@@ -62,9 +62,9 @@ static struct usbdb_entry {
 	int (*bnmap)(int);		/* remap buttons on problematic devices */
 } usbdb[] = {
 	{{0x046d, 0xc603}, DEV_PLUSXT,		0,						0},				/* spacemouse plus XT */
-	{{0x046d, 0xc605}, DEV_CADMAN,		0,						0},				/* cadman */
+	{{0x046d, 0xc605}, DEV_CADMAN,		DF_SWAPYZ | DF_INVYZ,	0},				/* cadman */
 	{{0x046d, 0xc606}, DEV_SMCLASSIC,	0,						0},				/* spacemouse classic */
-	{{0x046d, 0xc621}, DEV_SB5000,		0,						0},				/* spaceball 5000 */
+	{{0x046d, 0xc621}, DEV_SB5000,		DF_SWAPYZ | DF_INVYZ,	0},				/* spaceball 5000 */
 	{{0x046d, 0xc623}, DEV_STRAVEL,		DF_SWAPYZ | DF_INVYZ,	0},				/* space traveller */
 	{{0x046d, 0xc625}, DEV_SPILOT,		DF_SWAPYZ | DF_INVYZ,	0},				/* space pilot */
 	{{0x046d, 0xc626}, DEV_SNAV,		DF_SWAPYZ | DF_INVYZ,	0},				/* space navigator */
@@ -80,7 +80,7 @@ static struct usbdb_entry {
 	{{0x256f, 0xc633}, DEV_SMENT,		DF_SWAPYZ | DF_INVYZ,	bnhack_sment},	/* spacemouse enterprise */
 	{{0x256f, 0xc635}, DEV_SMCOMP,		DF_SWAPYZ | DF_INVYZ,	0},				/* spacemouse compact */
 	{{0x256f, 0xc636}, DEV_SMMOD,		DF_SWAPYZ | DF_INVYZ,	0},				/* spacemouse module */
-
+	{{0x256f, 0xc63a}, DEV_SMW,			DF_SWAPYZ | DF_INVYZ,	0},				/* spacemouse wireless (Bluetooth) */
 	{{-1, -1}, DEV_UNKNOWN, 0}
 };
 
@@ -90,6 +90,14 @@ static struct usbdb_entry {
 static int devid_blacklist[][2] = {
 	{0x256f, 0xc650},	/* cadmouse */
 	{0x256f, 0xc651},	/* cadmouse wireless */
+	{0x256f, 0xc654},	/* CadMouse Pro Wireless */
+	{0x256f, 0xc655},	/* CadMouse Compact */
+	{0x256f, 0xc656},	/* CadMouse Pro */
+	{0x256f, 0xc657},	/* CadMouse Pro Wireless Left */
+	{0x256f, 0xc658},	/* CadMouse Compact Wireless */
+	{0x256f, 0xc664},	/* Keyboard Pro */
+	{0x256f, 0xc668},	/* Keyboard Pro (newer version)*/
+	{0x256f, 0xc665},	/* Numpad Pro */
 	{0x256f, 0xc62c},	/* lipari(?) */
 	{0x256f, 0xc641},	/* scout(?) */
 
