@@ -1,6 +1,6 @@
 /*
 spacenavd - a free software replacement driver for 6dof space-mice.
-Copyright (C) 2007-2021 John Tsiombikas <nuclear@member.fsf.org>
+Copyright (C) 2007-2023 John Tsiombikas <nuclear@member.fsf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -106,6 +106,8 @@ static int read_timeout(int fd, char *buf, int bufsz, long tm_usec);
 static void enqueue_motion(struct sball *sb, int axis, int val);
 static void gen_button_events(struct sball *sb, unsigned int prev);
 
+static char *memstr(char *buf, int len, const char *str);
+
 
 int open_dev_serial(struct device *dev)
 {
@@ -147,7 +149,7 @@ int open_dev_serial(struct device *dev)
 
 	write(fd, "\r@RESET\r", 8);
 
-	if((sz = read_timeout(fd, buf, sizeof buf - 1, 2000000)) > 0 && (buf[sz] = 0, strstr(buf, "@1"))) {
+	if((sz = read_timeout(fd, buf, sizeof buf - 1, 2000000)) > 0 && memstr(buf, sz, "@1")) {
 		/* we got a response, so it's a spaceball */
 		make_printable(buf, sz);
 		logmsg(LOG_INFO, "Spaceball detected: %s\n", buf);
@@ -184,6 +186,8 @@ int open_dev_serial(struct device *dev)
 
 		/* set 3D mode, not-dominant-axis, pass through motion and button packets */
 		write(fd, "m3\r", 3);
+		/* also attempt the compress mode-set command with extended keys enabled */
+		write(fd, "c3B\r", 4);
 
 		sb->parse = mag_parsepkt;
 		return 0;
@@ -604,7 +608,7 @@ static int guess_num_buttons(struct device *dev, const char *verstr)
 	if(strstr(verstr, "MAGELLAN")) {
 		dev->type = DEV_SM;
 		strcpy(dev->name, "Magellan SpaceMouse");
-		return 9; /* magellan spacemouse */
+		return 11; /* magellan spacemouse (assume ext buttons on plus/xt) */
 	}
 
 	if(strstr(verstr, "SPACEBALL")) {
@@ -717,3 +721,14 @@ static void gen_button_events(struct sball *sb, unsigned int prev)
 		bit <<= 1;
 	}
 }
+
+static char *memstr(char *buf, int len, const char *str)
+{
+	int i, slen = strlen(str);
+	for(i=0; i<len - slen; i++) {
+		if(memcmp(buf + i, str, slen) == 0) {
+			return buf + i;
+		}
+	}
+	return 0;
+}
